# fret

[![Build Status](https://travis-ci.org/yxonic/fret.svg?branch=master)](https://travis-ci.org/yxonic/fret) [![Coverage Status](https://coveralls.io/repos/github/yxonic/fret/badge.svg?branch=master)](https://coveralls.io/github/yxonic/fret?branch=master)

Framework for Reproducible ExperimenTs

## TODO
- [x] Better configuration logic
- [x] `@fret.configurable` for modules
- [x] `@fret.command` for commands
- [ ] Global configuration file: `fret.toml`
- [ ] Workspace plugin system and plugins for torch and tf (try python mixin)
- [ ] Test coverage
- [ ] workspace utils (for snapshots, results, etc.)
- [ ] Documents and examples
- [ ] `fret new` command
- [ ] Other fret commands like log, show config, etc.
